==> besom-model_3-0.4.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"root","t":"root","d":"","k":"static","x":""},
{"l":"besom/model.html#","e":false,"i":"","n":"besom.model","t":"besom.model","d":"","k":"package","x":""},
{"l":"besom/model/SemanticVersion.html#","e":false,"i":"","n":"SemanticVersion","t":"SemanticVersion(major: Int, minor: Int, patch: Int, preRelease: Option[String], buildMetadata: Option[String]) extends Ordered[SemanticVersion]","d":"besom.model","k":"class","x":""},
{"l":"besom/model/SemanticVersion.html#buildMetadataString-0","e":false,"i":"","n":"buildMetadataString","t":"buildMetadataString: String","d":"besom.model.SemanticVersion","k":"val","x":""},
{"l":"besom/model/SemanticVersion.html#isSnapshot-0","e":false,"i":"","n":"isSnapshot","t":"isSnapshot: Boolean","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion.html#preReleaseString-0","e":false,"i":"","n":"preReleaseString","t":"preReleaseString: String","d":"besom.model.SemanticVersion","k":"val","x":""},
{"l":"besom/model/SemanticVersion.html#toShortString-0","e":false,"i":"","n":"toShortString","t":"toShortString: String","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion$.html#","e":false,"i":"","n":"SemanticVersion","t":"SemanticVersion","d":"besom.model","k":"object","x":""},
{"l":"besom/model/SemanticVersion$.html#apply-26","e":false,"i":"","n":"apply","t":"apply(major: Int, minor: Int, patch: Int): SemanticVersion","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion$.html#apply-a1","e":false,"i":"","n":"apply","t":"apply(major: Int, minor: Int, patch: Int, preRelease: String): SemanticVersion","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion$.html#apply-b1c","e":false,"i":"","n":"apply","t":"apply(major: Int, minor: Int, patch: Int, preRelease: String, buildMetadata: String): SemanticVersion","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion$.html#parse-fffffbe4","e":false,"i":"","n":"parse","t":"parse(version: String): Either[Exception, SemanticVersion]","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion$.html#parseTolerant-fffffbe4","e":false,"i":"","n":"parseTolerant","t":"parseTolerant(version: String): Either[Exception, SemanticVersion]","d":"besom.model.SemanticVersion","k":"def","x":""}];

==> besom-model_3-0.5.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"root","t":"root","d":"","k":"static","x":""},
{"l":"besom/model.html#","e":false,"i":"","n":"besom.model","t":"besom.model","d":"","k":"package","x":""},
{"l":"besom/model/NameMangler$.html#","e":false,"i":"","n":"NameMangler","t":"NameMangler","d":"besom.model","k":"object","x":""},
{"l":"besom/model/NameMangler$.html#isReserved-fffffd1b","e":false,"i":"","n":"isReserved","t":"isReserved(name: String): Boolean","d":"besom.model.NameMangler","k":"def","x":""},
{"l":"besom/model/NameMangler$.html#manglePropertyName-fffff2ca","e":false,"i":"","n":"manglePropertyName","t":"manglePropertyName(name: String): String","d":"besom.model.NameMangler","k":"def","x":""},
{"l":"besom/model/NameMangler$.html#unmanglePropertyName-fffff2ca","e":false,"i":"","n":"unmanglePropertyName","t":"unmanglePropertyName(name: String): String","d":"besom.model.NameMangler","k":"def","x":""},
{"l":"besom/model/SemanticVersion.html#","e":false,"i":"","n":"SemanticVersion","t":"SemanticVersion(major: Int, minor: Int, patch: Int, preRelease: Option[String], buildMetadata: Option[String]) extends Ordered[SemanticVersion]","d":"besom.model","k":"class","x":""},
{"l":"besom/model/SemanticVersion.html#buildMetadataString-0","e":false,"i":"","n":"buildMetadataString","t":"buildMetadataString: String","d":"besom.model.SemanticVersion","k":"val","x":""},
{"l":"besom/model/SemanticVersion.html#isSnapshot-0","e":false,"i":"","n":"isSnapshot","t":"isSnapshot: Boolean","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion.html#preReleaseString-0","e":false,"i":"","n":"preReleaseString","t":"preReleaseString: String","d":"besom.model.SemanticVersion","k":"val","x":""},
{"l":"besom/model/SemanticVersion.html#toShortString-0","e":false,"i":"","n":"toShortString","t":"toShortString: String","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion$.html#","e":false,"i":"","n":"SemanticVersion","t":"SemanticVersion","d":"besom.model","k":"object","x":""},
{"l":"besom/model/SemanticVersion$.html#apply-26","e":false,"i":"","n":"apply","t":"apply(major: Int, minor: Int, patch: Int): SemanticVersion","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion$.html#apply-a1","e":false,"i":"","n":"apply","t":"apply(major: Int, minor: Int, patch: Int, preRelease: String): SemanticVersion","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion$.html#apply-b1c","e":false,"i":"","n":"apply","t":"apply(major: Int, minor: Int, patch: Int, preRelease: String, buildMetadata: String): SemanticVersion","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion$.html#parse-fffffbe4","e":false,"i":"","n":"parse","t":"parse(version: String): Either[Exception, SemanticVersion]","d":"besom.model.SemanticVersion","k":"def","x":""},
{"l":"besom/model/SemanticVersion$.html#parseTolerant-fffffbe4","e":false,"i":"","n":"parseTolerant","t":"parseTolerant(version: String): Either[Exception, SemanticVersion]","d":"besom.model.SemanticVersion","k":"def","x":""}];
